# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SandboxResourcesParam"]


class SandboxResourcesParam(TypedDict, total=False):
    cpu_cores: int

    disk_gb: int

    memory_mb: int
